
==========
Preference
==========

.. autosummary::
    :toctree: api/

    prismstudio.preference.get_default_attributes
    prismstudio.preference.get_package_priority
    prismstudio.preference.set_default_attributes
    prismstudio.preference.set_package_priority
    prismstudio.preference.get_preference
    prismstudio.preference.set_preference

